@@ -1,8 +1,9 @@
 use strict;
 use warnings;
+use 5.006;
 package Dist::Zilla::Catalyst::Helper;
 BEGIN {
-	our $VERSION = 0.13;# VERSION
+	our $VERSION = 0.14;# VERSION
 }
 use Moose;
 use Dist::Zilla::File::InMemory;
@@ -22,7 +23,6 @@ has _zilla_gatherer => (
 sub _mk_changes {};
 sub _mk_makefile {};
 sub _mk_readme {};
-sub _mk_apptest {};
 sub _mk_podtest {};
 sub _mk_podcoveragetest {};
 sub mk_dir {};
@@ -67,7 +67,7 @@ Dist::Zilla::Catalyst::Helper - a subclass of Catalyst::Helper
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 DESCRIPTION
 
